@@ -20,7 +20,7 @@ class ArbitraryBinaryArray:  # pylint: disable=too-few-public-methods
     def __arrow_array__(self) -> pa.Array:
         # convert the underlying array values to a pyarrow Array
         mem_file = BytesIO()
-        np.save(mem_file, self.val)  # type: ignore
+        np.save(mem_file, self.val)
         return pa.array([bytearray(mem_file.getvalue())], pa.binary())
 
 
