@@ -29,7 +29,7 @@ def numpy_deserialize(
 
     """
     del sample
-    return np.array(value)
+    return np.array(value, dtype=object)
 
 
 def numpy_serialize(*, value: npt.NDArray[t.Any]) -> str:
